package v3

import (
	"encoding/json"
	"htwkalender/service/functions"
	"net/http"

	"log/slog"
)

func parseSeminarGroups(url string, client *http.Client) (seminarGroups, error) {

	// the url is paginated, so we need to fetch all pages
	// example url: https://luna.htwk-leipzig.de/api/studierendengruppen?page=1&itemsPerPage=100
	// the itemsPerPage is set to 100, so we need to fetch all pages until we get an empty response

	var fetchedSeminarGroups []seminarGroup
	var page = 1
	var itemsPerPage = 999
	var totalItems = 0

	responses, err := paginatedFetch(url, itemsPerPage, client)

	if err != nil {
		slog.Error("Error while fetching seminar groups", err)
		return seminarGroups{}, err
	}

	for _, response := range responses {
		var groups seminarGroups
		err = json.Unmarshal([]byte(response), &groups)
		if err != nil {
			slog.Error("Error while unmarshalling seminar groups", err)
			return seminarGroups{}, err
		}

		// cut api iri prefix
		for i, group := range groups.Groups {
			//keep the last 32 characters of the string
			groups.Groups[i].Faculty = functions.RemoveIriPrefix(group.Faculty, 32)
			groups.Groups[i].Studiengang = functions.RemoveIriPrefix(group.Studiengang, 32)
			groups.Groups[i].Semester = functions.RemoveIriPrefix(group.Semester, 2)
		}

		totalItems = groups.TotalItems
		fetchedSeminarGroups = append(fetchedSeminarGroups, groups.Groups...)

		if len(groups.Groups) == 0 {
			break
		}
		page++
	}

	return seminarGroups{
		TotalItems: totalItems,
		Groups:     fetchedSeminarGroups,
	}, nil

}
