package v3

import (
	"encoding/json"
	"log/slog"
	"net/http"
)

func parseStudyTypes(url string, client *http.Client) ([]studyType, error) {

	// the url is paginated, so we need to fetch all pages
	// example url: https://luna.htwk-leipzig.de/api/studiengangstypen?page=1&itemsPerPage=100
	// the itemsPerPage is set to 100, so we need to fetch all pages until we get an empty response

	var fetchedStudyTypes []studyType
	var itemsPerPage = 999

	responses, err := paginatedFetch(url, itemsPerPage, client)

	if err != nil {
		slog.Error("Error while fetching study types", err)
		return nil, err
	}

	for _, response := range responses {
		var types studyTypes
		err = json.Unmarshal([]byte(response), &types)
		if err != nil {
			slog.Error("Error while unmarshalling study types", err)
			return nil, err
		}

		fetchedStudyTypes = append(fetchedStudyTypes, types.Types...)
	}

	return fetchedStudyTypes, nil
}
